#!/usr/bin/env python3

import os
import shutil
import sys


CMD = (
    "ffmpeg -loglevel error -i {inputfile!r} "
    "-max_muxing_queue_size 99999 "  # temp bug?
    # "-pix_fmt yuv420p "  # para sacarlo de yuv420p10le
    "-c:v libx264 -preset slow -crf 20 "  # H.264, very good quality, good compression rate
    "-c:a libmp3lame -qscale:a 2 "  # mp3, very good quality
    "{outputile!r}"
)


def main(inp_fname):
    out_fname = inp_fname[:-4] + ".mkv"

    if out_fname == inp_fname:
        # rename input so don't collide
        alt_inp_fname = inp_fname[:-4] + "--original.mkv"
        os.rename(inp_fname, alt_inp_fname)
        inp_fname = alt_inp_fname

    # assure env is ok
    print("Processing", inp_fname)
    assert os.path.exists(inp_fname)
    assert not os.path.exists(out_fname)

    cmd = CMD.format(inputfile=inp_fname, outputile=out_fname)
    status = os.system(cmd)
    if status != 0:
        print("ERROR, status:", status)
        exit()

    # move the old one to /tmp, to take it from the working dir (but don't just remove it, JIC)
    shutil.move(inp_fname, "/home/facundo/temp/" + inp_fname + ".backup")


if __name__ == '__main__':
    def die():
        print("Usage: {} input [input [...]]".format(sys.argv[0]))
        exit()

    if len(sys.argv) < 2:
        die()

    for fname in sys.argv[1:]:
        main(fname)
